pub struct Html<T: Write> { /* private fields */ }
An adaptor to allow writing stylish attributed data to an output stream by turning attributes into HTML elements.

let mut writer = stylish::Html::new(String::new());
stylish::write!(writer, "Hello {:(fg=red)}", "Ferris")?;
assert_eq!(
    writer.finish()?,
    "Hello <span style=color:red>Ferris</span>",
);

Implementations

Wrap the given output stream in this adaptor.

Inherent delegation to stylish::Write::write_fmt to not require a trait import.

Ensure the output stream is reset back to the default style and return it, if you don’t call this the stream will be left in whatever style the last output data was.